summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xscripts/prep-librewolf-dpkg.sh5
1 files changed, 3 insertions, 2 deletions
diff --git a/scripts/prep-librewolf-dpkg.sh b/scripts/prep-librewolf-dpkg.sh
index 691706e..764fe34 100755
--- a/scripts/prep-librewolf-dpkg.sh
+++ b/scripts/prep-librewolf-dpkg.sh
@@ -201,8 +201,9 @@ else
"${debian_dir}"/patches/librewolf/
awk -F'/' '{print "librewolf/"$NF}' "${git_source_dir}"/source/assets/patches.txt | \
sed -r -e 's@$@ -p1@' >> "${debian_dir}"/patches/series
- # remove xmas because it does the same tasks as what we accomplish in this script.
- sed -i -r -e '/xmas\.patch/s/^/#/;' "${debian_dir}"/patches/series
+ # remove xmas because it does the same tasks as what we accomplish in this script,
+ # and librewolf-pren-pane because it is experimental
+ sed -i -r -e '/(xmas|librewolf-pref-pane)\.patch/s/^/#/;' "${debian_dir}"/patches/series
# Fixes to the LibreWolf patches for version 96.0.1.
# remove_addons.patch will be fixed when https://gitlab.com/librewolf-community/browser/source/-/merge_requests/10
test -n "a" && patch -p1 "${debian_dir}/patches/librewolf/remove_addons.patch" <<EOF
bgstack15